@@ -1,7 +1,7 @@
 package App::riap;
 
-our $DATE = '2015-03-04'; # DATE
-our $VERSION = '0.30'; # VERSION
+our $DATE = '2015-03-13'; # DATE
+our $VERSION = '0.31'; # VERSION
 
 use 5.010001;
 use strict;
@@ -294,6 +294,8 @@ sub state {
 }
 
 sub load_settings {
+    require Config::IOD::Reader;
+
     my $self = shift;
 
     my $filename = $self->settings_filename;
@@ -303,20 +305,11 @@ sub load_settings {
         last unless $filename;
         last unless (-e $filename);
         $log->tracef("Loading settings from %s ...", $filename);
-        open(my $fh, '<', $filename)
-            or die "Can't open settings file $filename: $!\n";
-        my $lineno = 0;
-        while (<$fh>) {
-            $lineno++;
-            next unless /\S/;
-            next if /^#/;
-            my ($n, $v) = /(.+?)\s*=\s*(.+)/
-                or die "$filename:$lineno: Invalid syntax in settings file\n";
-            eval { $v = $self->json_decode($v) };
-            $@ and die "$filename:$lineno: Invalid JSON in setting value: $@\n";
-            $self->setting($n, $v);
+        my $res = Config::IOD::Reader->new->read_file($filename);
+        last unless $res->{GLOBAL};
+        for (sort keys %{$res->{GLOBAL}}) {
+            $self->setting($_, $res->{GLOBAL}{$_});
         }
-        close $fh;
     }
 }
 
@@ -740,7 +733,7 @@ App::riap - Riap command-line client shell
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
