@@ -1,7 +1,7 @@
 package App::riap::Commands;
 
-our $DATE = '2015-03-04'; # DATE
-our $VERSION = '0.30'; # VERSION
+our $DATE = '2015-03-13'; # DATE
+our $VERSION = '0.31'; # VERSION
 
 use 5.010;
 use strict;
@@ -166,14 +166,11 @@ sub ls {
             }
             my $ff = [qw/type uri v date summary/];
             my $rfo = {
-                table_column_orders => [$ff],
+
             };
             $resmeta = {
-                "result_format_options" => {
-                    "text"        => $rfo,
-                    "text-simple" => $rfo,
-                },
-                "table.fields" => $ff,
+                "format_options" => {any=>{table_column_orders => [$ff]}},
+                "table.fields"   => $ff,
             },
         } else {
             $res = $shell->riap_request(list => $uri);
@@ -324,10 +321,7 @@ sub set {
             };
         }
         my $rfo = {table_column_orders=>[[qw/name summary value default/]]};
-        [200, "OK", $res, {result_format_options=>{
-            text          => $rfo,
-            "text-pretty" => $rfo,
-        }}];
+        [200, "OK", $res, {format_options=>{any=>$rfo}}];
     }
 }
 
@@ -558,7 +552,7 @@ App::riap::Commands - riap shell commands
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =for Pod::Coverage .+
 
